package Baldrick;
use strict;

BEGIN {
    use Baldrick::Baldrick;
}

=head1 NAME

Baldrick - Baldrick Application Framework

=head1 SYNOPSIS

  use Baldrick::Baldrick;

=head1 DESCRIPTION

Baldrick.pm is the loader for the Baldrick Application Framework.

Baldrick::Stub.pm loads Baldrick.pm, and also provides the main() for a Baldrick
module.  See "perldoc Baldrick::Stub".

=head1 AUTHOR

    Matt Hucke
    CPAN ID: HUCKE
    hucke@cynico.net
    http://www.baldrickframework.org/

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

Baldrick::Stub

http://www.baldrickframework.org/

=cut

#################### main pod documentation end ###################

1;
